# -.- coding: utf-8 -.-

# Affinity
#
# Copyright © 2010 Seif Lotfy <seif@lotfy.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import MySQLdb
from conf import *
from zeitgeist.datamodel import Subject
# connect

class DB():
    def __init__(self):
        self.set_up()
    
    def set_up(self):
        self.db = MySQLdb.connect(host=DB_HOST, user=DB_USER, passwd=DB_PASSWD)
        # create a cursor
        self.cursor = self.db.cursor()
        self._create_db()
    
    def _create_db(self):
        self.cursor.execute("create database if not exists %s;" %DB_NAME)
        self.db = MySQLdb.connect(host=DB_HOST, user=DB_USER, passwd=DB_PASSWD, db=DB_NAME)
        # create a cursor
        self.cursor = self.db.cursor()
        self.cursor.execute("""
        CREATE TABLE IF NOT EXISTS event(
            id INT NOT NULL AUTO_INCREMENT,
            timestamp BIGINT,
            origin VARCHAR(255),
            interpretation VARCHAR(255),
            manifestation VARCHAR(255),             
            actor VARCHAR(255),
            subj_id VARCHAR(255),
            subj_interpretation VARCHAR(255),
            subj_manifestation VARCHAR(255),
            subj_origin VARCHAR(255),
            subj_mimetype VARCHAR(255),
            subj_text VARCHAR(255),
            PRIMARY KEY (id),
            UNIQUE (
                timestamp, 
                origin,
                actor,
                subj_id)
            );
        """)
        
    def insert_events(self, user, events):
        for event in events:
            self._insert_event(user, event)
              
    def _insert_event(self, user, event):
        if len(event.subjects) == 0:
            subject = Subject()
        else:
            subject = event.subjects[0]
        insert_cmd = """    INSERT IGNORE INTO event 
                            VALUES ('', %s, %s, %s, %s, %s, %s, %s, %s, %s, %s, %s)
                            """ % (event.timestamp,
                                  "'%s'" %user,
                                  "'%s'" %event.interpretation,
                                  "'%s'" %event.manifestation,
                                  "'%s'" %unicode(event.actor),
                                  "'%s'" %subject.uri,
                                  "'%s'" %subject.interpretation,
                                  "'%s'" %subject.manifestation,
                                  "'%s'" %subject.origin,
                                  "'%s'" %subject.mimetype,
                                  "'%s'" %subject.text,
                                  )
        self.cursor.execute(insert_cmd)

db = DB()